However, the Sense HAT showed some problems during the data collection. The first issue was with the Raspberry Pi's built-in Wi-Fi adapter, which was not compatible with the WLAN of the buildings where it was tested. To overcome it, the solution was to connect the the Raspberry Pi to Ethernet, compromising the mobility of the sensor. We also had problems caused due to undervoltage. Once the Raspberry Pi consumes more power when using the Sense HAT, it needs a more potent power supply, to which the authors did not have access. Due to these problems, we decided to change the scope of the project and collect the weather data from public sources. The data was provided by the National Centers for Environmental Information (NCEI), a department of U.S. National Oceanic and Atmospheric Administration (NOAA). It contains sensor data such as temperature, pressure, humidity and wind direction that are measured at weather stations around the globe. Also it contains inputed data about the sky conditions, occurence of rain, snow, thunderstorms and other weather events. The data is provided in a daily basis with hourly measurements in a CSV file, with each file corresponding to a specific station. To our use case we used the data provided by a station located at Berlin Tegel airport.

In order to have a smooth running process we chose to use the LUIGI library in Python to orchestrate our process. LUIGI is a library developed by Spotify that helps with dependency resolution and task management. 

The task list for the LUIGI job was defined in four classes. Each class was responsible for one task, while LUIGI handled the dependency resolution for each. In this way, running the last task would ensure that all dependencies of that task will run as well. 


## Semantic web of things and Blockchain

Semantic Web of Things (SWoT) refers to the integration of Semantic Web technologies to the IoT ecossystem \cite{scioscia2009building}. It allows to enrich the information provided by IoT devices, boosting the capability to scale IoT applications. By embedding intelligence in the generated data by a large number of devices, the whole set of data becomes richer \cite{ruta2017semantic}. In this way, the network becomes more inteligent, since machines can handle and interpret semantic content \cite{mediuma}.

However the Semantic Web did not have a popular acceptance by the IoT and Web ecossystem. Although it is popular on the academic world, its potential is not understood on the business environment. Also, some researches claim that it is a utopia to semantically link the exponential amount of data currently generated, and that other techniques, such as Machine Learning, could handle better this situation. An emerging idea among the academia is to adopt some of Semantic Web concepts in Blockchain architecture design. These new networks fuelled by Smart Contracts can be used as the kernel for a new family of AI agents \cite{ugarte2017more}.

A practical application of these concepts is the utilization of Linked Data to index Distributed Ledgers \cite{Third2017}. Linked Data is known as the standard form to implement Semantic Web, which should follow four principles \cite{issues}:

1. Use of Uniform Resource Identifiers (URIs) to name things

2. Use HTTP URIs to make things accessible to people

3. Provide useful information, using the standards RDF* and SPARQL when someone someone looks up a URI

4. Programatically connect URIs by including links to other URIs to make things easier to be discovered

In \cite{Third2017}, the authors proposed a semantic index to Ethereum Blockchain network to expose distributed ledger data as Linked Data. This approach facilitates to search for information in distributed ledgers, since neither Blockchain networks or distributed file systems have a central registry of the data stored on it. With their proposal it is possible to query and retrieve data stored in different locations over a Blockchain network. It is also possible to link this data with external applications using Blockchain Smart Contracts and Semantic Web Service tools. The authors used a vocabulary focused on Blockchain called BLONDiE.

Altough we understood the possibilities given by this approach, this technology was not useful to our use case, given that we did not have a large amount of data. The adoption of this technology would not give us good results in terms of increasing performance or making the implementation easier.

## Dashboard

The dashboard is the front-end application of our solution. It is a simple HTML5 page which retrieves the data from CSV files stored in an IPFS directory and displays the results in two time-series (for hourly temperature and dewpoint) charts built using D3.js. An example of the dashboard is shown in the Figure \ref{535576}.

